==> eksctl-0.56.0.tar.gz: eksctl-0.56.0/COMMUNITY.md <==
# eksctl community

Welcome to the eksctl community. We are very happy to have you here :tada: .

This document contains the following information:

- [Who the core team members are](#core-team)
- [How to join the community](#join-us) and get in touch with the core team
- [How eksctl is run](#how-eksctl-is-run) and how decisions are made
- [Community meetings](#community-meetings)
- [Community rules](#community-rules)

Ready to start contributing? Head over to our [contribution docs](CONTRIBUTING.md) :man_technologist:.

## Core team

The core team of maintainers are Chetan Patwal ([@cPu1](https://github.com/cPu1)),
Jake Klein ([@aclevername](https://github.com/aclevername)),
Niki Manoledaki ([@nikimanoledaki](https://github.com/nikimanoledaki)),
Gergely Brautigam ([@Skarlso](https://github.com/Skarlso)),
and Claudia Beresford ([@Callisto13](https://github.com/Callisto13)).

## Join us!

The project uses Slack. If you get stuck or just have a question then you are encouraged to join the
[Weave Community](https://slack.weave.works/) Slack workspace and use the
[#eksctl](https://weave-community.slack.com/messages/eksctl/) channel.

## How eksctl is run

Eksctl is an open-source project built to interact with a closed-source product.
This means that 99% of the project operates like any other open-source one,
with 1% of things happening in slightly secretive fashion as the maintainers
work with the folks at Amazon to synchronise the release of cool new EKS stuff :sunglasses: .

For that 99%, we strive to keep development open, and transparent.
Work is driven through partnership with AWS and the needs of the community.
We welcome all contributions and user feedback to the project.

**The roles in the eksctl community are as follows:**
- End users. In other words the reason why we are all here!
- Community contributors. These could be end users themselves, or those working
  on their open-source game.
- Maintainers. _See [the maintainer docs](https://github.com/weaveworks/eksctl-handbook) for a list
  of maintainer responsibilities._

Decisions are made by Maintainers with input from both Amazon and the community.
All the decisions which can be made publicly will take into account the opinions
of all in the community with sufficient opportunity given for those interested
to get involved.

## Community meetings

_A new schedule and format for community meetings is being worked out... watch this space! :space_invader: :eyes:_

## Community rules

The main one is **Always be kind**, and the rest can be found in our [Code of Conduct](CODE_OF_CONDUCT.md).

==> eksctl-0.85.0.tar.gz: eksctl-0.85.0/COMMUNITY.md <==
# eksctl community

Welcome to the eksctl community. We are very happy to have you here :tada: .

This document contains the following information:

- [Who the core team members are](#core-team)
- [How to join the community](#join-us) and get in touch with the core team
- [How eksctl is run](#how-eksctl-is-run) and how decisions are made
- [Community meetings](#community-meetings)
- [Community rules](#community-rules)

Ready to start contributing? Head over to our [contribution docs](CONTRIBUTING.md) :man_technologist:.

## Core team

The core team of maintainers are Chetan Patwal ([@cPu1](https://github.com/cPu1)),
Jake Klein ([@aclevername](https://github.com/aclevername)),
Niki Manoledaki ([@nikimanoledaki](https://github.com/nikimanoledaki)),
Gergely Brautigam ([@Skarlso](https://github.com/Skarlso)),
and Himangini Daware ([@Himangini](https://github.com/Himangini)).

## Join us!

The project uses Slack. If you get stuck or just have a question then you are encouraged to join the
[Weave Community](https://slack.weave.works/) Slack workspace and use the
[#eksctl](https://weave-community.slack.com/messages/eksctl/) channel.

## How eksctl is run

Eksctl is an open-source project built to interact with a closed-source product.
This means that 99% of the project operates like any other open-source one,
with 1% of things happening in slightly secretive fashion as the maintainers
work with the folks at Amazon to synchronise the release of cool new EKS stuff :sunglasses: .

For that 99%, we strive to keep development open, and transparent.
Work is driven through partnership with AWS and the needs of the community.
We welcome all contributions and user feedback to the project.

**The roles in the eksctl community are as follows:**
- End users. In other words the reason why we are all here!
- Community contributors. These could be end users themselves, or those working
  on their open-source game.
- Maintainers. _See [the maintainer docs](https://github.com/weaveworks/eksctl-handbook) for a list
  of maintainer responsibilities._

Decisions are made by Maintainers with input from both Amazon and the community.
All the decisions which can be made publicly will take into account the opinions
of all in the community with sufficient opportunity given for those interested
to get involved.

## Community meetings

_A new schedule and format for community meetings is being worked out... watch this space! :space_invader: :eyes:_

## Community rules

The main one is **Always be kind**, and the rest can be found in our [Code of Conduct](CODE_OF_CONDUCT.md).
